==> gammaray_2.1.0.orig.tar.xz: gammaray-2.1.0/core/toolpluginerrormodel.h <==
/*
  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2012-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Kevin Funk <kevin.funk@kdab.com>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GAMMARAY_TOOLPLUGINERRORMODEL_H
#define GAMMARAY_TOOLPLUGINERRORMODEL_H

#include <common/pluginmanager.h>

#include <QAbstractTableModel>

namespace GammaRay {

/** List of plugin loading errors on the target. */
class ToolPluginErrorModel : public QAbstractTableModel
{
    Q_OBJECT
public:
    explicit ToolPluginErrorModel(const PluginLoadErrors &errors, QObject *parent = 0);
    ~ToolPluginErrorModel();

    QVariant data(const QModelIndex& index, int role) const;
    int columnCount(const QModelIndex& parent) const;
    int rowCount(const QModelIndex& parent) const;
    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;

private:
    PluginLoadErrors m_errors;
};
}

#endif // GAMMARAY_TOOLPLUGINERRORMODEL_H

==> gammaray_2.5.1.orig.tar.xz: gammaray-2.5.1/core/toolpluginerrormodel.h <==
/*
  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2012-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Kevin Funk <kevin.funk@kdab.com>

  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
  accordance with GammaRay Commercial License Agreement provided with the Software.

  Contact info@kdab.com if any conditions of this licensing are not clear to you.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GAMMARAY_TOOLPLUGINERRORMODEL_H
#define GAMMARAY_TOOLPLUGINERRORMODEL_H

#include <common/pluginmanager.h>

#include <QAbstractTableModel>

namespace GammaRay {
/** List of plugin loading errors on the target. */
class ToolPluginErrorModel : public QAbstractTableModel
{
    Q_OBJECT
public:
    explicit ToolPluginErrorModel(const PluginLoadErrors &errors, QObject *parent = 0);
    ~ToolPluginErrorModel();

    QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE;
    int columnCount(const QModelIndex &parent) const Q_DECL_OVERRIDE;
    int rowCount(const QModelIndex &parent) const Q_DECL_OVERRIDE;
    QVariant headerData(int section, Qt::Orientation orientation,
                        int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;

private:
    PluginLoadErrors m_errors;
};
}

#endif // GAMMARAY_TOOLPLUGINERRORMODEL_H
